@@ -1,10 +1,9 @@
 # -*- coding: utf-8 -*-
 from datetime import datetime, timedelta
-from django.contrib.auth.models import User
-from django_nopassword.models import LoginCode
+from django.conf import settings
 
-#Todo: move to settings
-TIMEOUT = timedelta(minutes=15)
+from django_nopassword.utils import User
+from django_nopassword.models import LoginCode
 
 
 class EmailBackend:
@@ -15,13 +14,13 @@ class EmailBackend:
             if code is None:
                 return LoginCode.create_code_for_user(user)
             else:
-                timestamp = datetime.now() + TIMEOUT
-                login_code = LoginCode.objects.get(user=user, code=code, timestamp__lt=timestamp)
+                timestamp = datetime.now() - timedelta(seconds=getattr(settings, 'LOGIN_CODE_TIMEOUT', 900))
+                login_code = LoginCode.objects.get(user=user, code=code, timestamp__gt=timestamp)
                 user = login_code.user
                 user.code = login_code
                 login_code.delete()
                 return user
-        except (TypeError, User.DoesNotExist):
+        except (TypeError, User.DoesNotExist, LoginCode.DoesNotExist):
             return None
 
     def get_user(self, user_id):
