@@ -1,9 +1,13 @@
 # -*- coding: utf8 -*-
+import time
+
+from django.conf import settings
 from django.contrib.auth import authenticate
-from django.contrib.auth.models import User
+from django.test.utils import override_settings
 from django.utils import unittest
 
 from django_nopassword.models import LoginCode
+from django_nopassword.utils import User
 
 
 class TestLoginCodes(unittest.TestCase):
@@ -16,5 +20,11 @@ class TestLoginCodes(unittest.TestCase):
         self.assertIsNotNone(authenticate(username=self.user.username, code=self.code.code))
         self.assertEqual(LoginCode.objects.filter(user=self.user, code=self.code.code).count(), 0)
 
+    @override_settings(LOGIN_CODE_TIMEOUT=1)
+    def test_code_timeout(self):
+        self.timeout_code = LoginCode.create_code_for_user(self.user)
+        time.sleep(3)
+        self.assertIsNone(authenticate(username=self.user.username, code=self.timeout_code.code))
+
     def tearDown(self):
         self.user.delete()
